@@ -35,8 +35,7 @@ my %offOn = (
         Name => 'SanyoThumbnail',
         Writable => 'undef',
         WriteCheck => '$self->CheckImage(\$val)',
-        ValueConv => '$self->ValidateImage(\$val,$tag)',
-        ValueConvInv => '$val',
+        RawConv => '$self->ValidateImage(\$val,$tag)',
     },
     0x0200 => {
         Name => 'SpecialMode',
@@ -313,7 +312,7 @@ my %offOn = (
         Name => 'ThumbnailImage',
         Notes => 'position varies',
         Format => 'undef[$size - 0x800]',
-        ValueConv => '$val=~s/.*(?=\xff\xd8\xff\xc4)//; $self->ValidateImage(\$val,$tag)',
+        RawConv => '$val=~s/.*(?=\xff\xd8\xff\xc4)//; $self->ValidateImage(\$val,$tag)',
     },
 );
 
@@ -354,7 +353,7 @@ Sanyo maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2008, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2009, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
