@@ -103,17 +103,24 @@ sub WritePhotoshop($$$)
         if ($$newTags{$tagID} and $type eq '8BIM') {
             $tagInfo = $$newTags{$tagID};
             delete $$newTags{$tagID};
-            my $newValueHash = $exifTool->GetNewValueHash($tagInfo);
+            my $nvHash = $exifTool->GetNewValueHash($tagInfo);
             # check to see if we are overwriting this tag
             $value = substr($$dataPt, $pos, $size);
-            if (Image::ExifTool::IsOverwriting($newValueHash, $value)) {
-                $verbose > 1 and print $out "    - Photoshop:$$tagInfo{Name} = '$value'\n";
-                $value = Image::ExifTool::GetNewValues($newValueHash);
+            if (Image::ExifTool::IsOverwriting($nvHash, $value)) {
+                $exifTool->VerboseValue("- Photoshop:$$tagInfo{Name}", $value);
+                # handle IPTCDigest specially because we want to write it last
+                # so the new IPTC digest will be known
+                if ($tagID == 0x0425) {
+                    $$newTags{$tagID} = $tagInfo;   # add later
+                    $value = undef;
+                } else {
+                    $value = Image::ExifTool::GetNewValues($nvHash);
+                }
                 ++$exifTool->{CHANGED};
                 next unless defined $value;     # next if tag is being deleted
                 # set resource name if necessary
                 SetResourceName($tagInfo, $name, \$value);
-                $verbose > 1 and print $out "    + Photoshop:$$tagInfo{Name} = '$value'\n";
+                $exifTool->VerboseValue("+ Photoshop:$$tagInfo{Name}", $value);
             }
         } else {
             if ($type eq '8BIM') {
@@ -167,12 +174,16 @@ sub WritePhotoshop($$$)
         my $name = "\0\0";
         if ($$newTags{$tagID}) {
             $tagInfo = $$newTags{$tagID};
-            my $newValueHash = $exifTool->GetNewValueHash($tagInfo);
-            $value = Image::ExifTool::GetNewValues($newValueHash);
+            my $nvHash = $exifTool->GetNewValueHash($tagInfo);
+            $value = Image::ExifTool::GetNewValues($nvHash);
+            # handle new IPTCDigest value specially
+            if ($tagID == 0x0425 and defined $value and $value eq 'new') {
+                $value = $$exifTool{NewIPTCDigest};
+            }
             next unless defined $value;     # next if tag is being deleted
             # don't add this tag unless specified
-            next unless Image::ExifTool::IsCreating($newValueHash);
-            $verbose > 1 and print $out "    + Photoshop:$$tagInfo{Name} = '$value'\n";
+            next unless Image::ExifTool::IsCreating($nvHash);
+            $exifTool->VerboseValue("+ Photoshop:$$tagInfo{Name}", $value);
             ++$exifTool->{CHANGED};
         } else {
             $tagInfo = $$addDirs{$tagID};
@@ -226,7 +237,7 @@ default resource name, and applied if no appended name is provided.
 
 =head1 AUTHOR
 
-Copyright 2003-2007, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2009, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
